@@ -106,10 +106,10 @@ class BaseOperator(metaclass=abc.ABCMeta):
             for tid in list(self.airflow_context['task'].upstream_task_ids):
                 self.upstream_task_xcom[tid] = self.airflow_context['ti'].xcom_pull(task_ids=tid) 
         elif self.deploy_mode == "local-bash":
-            with open("/opt/mnt/fs/tmp/xcom_input.json") as f:
+            with open("/opt/airflow/flowui/xcom/xcom_input.json") as f:
                 self.upstream_task_xcom = json.load(f)
         elif self.deploy_mode == "local-k8s":
-            with open("/opt/mnt/fs/tmp/xcom_input.json") as f:
+            with open("/opt/airflow/flowui/xcom/xcom_input.json") as f:
                 self.upstream_task_xcom = json.load(f)
         else:
             raise NotImplementedError(f"Get upstream XCOM not implemented for deploy_mode=={self.deploy_mode}")
