@@ -17,7 +17,7 @@ import shutil
 
 from flowui.scripts.build_docker_images_operators import build_images_from_operators_repository
 from flowui.scripts.create_docker_compose_file import create_docker_compose_file
-from flowui.scripts.run_operator_docker import run_operator as run_operator_in_docker
+from flowui.scripts.run_operator_k8s import run_operator as run_operator_in_k8s
 from flowui.scripts.run_operator_bash import run_operator as run_operator_in_bash
 from flowui.scripts.load_operator import load_operator_models_from_path
 from flowui.client.github_rest_client import GithubRestClient
@@ -99,7 +99,7 @@ class CommandLineInterface:
             'stop', 
             'create-operators-repository',
             'organize', 
-            'run-operator-docker', 
+            'run-operator-k8s', 
             'run-operator-bash', 
         ]
         parser.add_argument(
@@ -684,10 +684,10 @@ class CommandLineInterface:
                 json.dump(updated_dependencies_map, outfile, indent=4)
 
 
-    def run_operator_in_docker(self) -> None:
+    def run_operator_in_k8s(self) -> None:
         """Convenience function to run Operators within Docker images"""
         self.logger.info("Running Operator...")
-        run_operator_in_docker()
+        run_operator_in_k8s()
     
 
     def run_operator_in_bash(self) -> None:
@@ -711,7 +711,7 @@ def cli():
         "organize": cli.organize_operators_repository,
         
         # Run Operator
-        "run-operator-docker": cli.run_operator_in_docker,
+        "run-operator-k8s": cli.run_operator_in_k8s,
         "run-operator-bash": cli.run_operator_in_bash,
     }
     cli_func_map[cli_args.action]()
